@@ -53,8 +53,10 @@ class Net_DNS_RR_SOA extends Net_DNS_RR
 
         if ($offset) {
             if ($this->rdlength > 0) {
-                list($mname, $offset) = Net_DNS_Packet::dn_expand($data, $offset);
-                list($rname, $offset) = Net_DNS_Packet::dn_expand($data, $offset);
+                $packet = new Net_DNS_Packet();
+
+                list($mname, $offset) = $packet->dn_expand($data, $offset);
+                list($rname, $offset) = $packet->dn_expand($data, $offset);
 
                 $a = unpack("@$offset/N5soavals", $data);
                 $this->mname = $mname;
@@ -65,11 +67,19 @@ class Net_DNS_RR_SOA extends Net_DNS_RR
                 $this->expire = $a['soavals4'];
                 $this->minimum = $a['soavals5'];
             }
+        } elseif (is_array($data)) {
+            $this->mname = $data['mname'];
+            $this->rname = $data['rname'];
+            $this->serial = $data['serial'];
+            $this->refresh = $data['refresh'];
+            $this->retry = $data['retry'];
+            $this->expire = $data['expire'];
+            $this->minimum = $data['minimum'];
         } else {
-            if (ereg("([^ \t]+)[ \t]+([^ \t]+)[ \t]+([0-9]+)[^ \t]+([0-9]+)[^ \t]+([0-9]+)[^ \t]+([0-9]+)[^ \t]*$", $string, $regs))
+            if (preg_match("/([^ \t]+)[ \t]+([^ \t]+)[ \t]+([0-9]+)[ \t]+([0-9]+)[ \t]+([0-9]+)[ \t]+([0-9]+)[ \t]+([0-9]+)[ \t]*$/", $data, $regs))
             {
-                $this->mname = ereg_replace('(.*)\.$', '\\1', $regs[1]);
-                $this->rname = ereg_replace('(.*)\.$', '\\1', $regs[2]);
+                $this->mname = preg_replace('/(.*)\.$/', '\\1', $regs[1]);
+                $this->rname = preg_replace('/(.*)\.$/', '\\1', $regs[2]);
                 $this->serial = $regs[3];
                 $this->refresh = $regs[4];
                 $this->retry = $regs[5];
@@ -131,4 +141,4 @@ class Net_DNS_RR_SOA extends Net_DNS_RR
  * vim600: sw=4 ts=4 sts=4 cindent fdm=marker et
  * vim<600: sw=4 ts=4
  * }}} */
-?>
\ No newline at end of file
+?>
