@@ -230,8 +230,26 @@ class Net_DNS_Resolver
      * @access private
      */
     var $_axfr_soa_count;
+     /**
+     * An array of config files that have been read/parsed already and is used
+     * to ensure the usable config files are searched for only once.
+     *
+     * @var array
+     * @access public
+     * @see Net_DNS_Resolver::read_config()
+     */
+    var $parsedfiles = array();
+    /**
+     * sleep
+     *
+     * Length of time to wait between reading for respose from server.
+     *
+     * @var int
+     * @access private
+     */
+    var $sleep;
 
-
+    /**
     /* }}} */
     /* class constructor - Net_DNS_Resolver() {{{ */
     /**
@@ -258,6 +276,7 @@ class Net_DNS_Resolver
                 'errorstring' => 'unknown error or no error',
                 'answerfrom'  => '',
                 'answersize'  => 0,
+                'sleep'       => 1000,
                 'tcp_timeout' => 120
                 );
         foreach ($mydefaults as $k => $v) {
@@ -284,13 +303,21 @@ class Net_DNS_Resolver
     function res_init()
     {
         $err = error_reporting(0);
-        if (file_exists($this->resolv_conf) && is_readable($this->resolv_conf)) {
-            $this->read_config($this->resolv_conf);
-        }
+        if ($this->parsedfiles == array()) {
+            if (file_exists($this->resolv_conf) && is_readable($this->resolv_conf)) {
+                $this->read_config($this->resolv_conf);
+                array_push($this->parsedfiles, $this->resolv_conf);
+            }
 
-        foreach ($this->confpath as $dir) {
-            $file = $dir.DIRECTORY_SEPARATOR.$this->dotfile;
-            if (file_exists($file) && is_readable($file)) {
+            foreach ($this->confpath as $dir) {
+                $file = $dir.DIRECTORY_SEPARATOR.$this->dotfile;
+                if (file_exists($file) && is_readable($file)) {
+                    $this->read_config($file);
+                    array_push($this->parsedfiles, $file);
+                }
+            }
+        } else {
+            foreach($this->parsedfiles as $file) {
                 $this->read_config($file);
             }
         }
@@ -325,32 +352,38 @@ class Net_DNS_Resolver
         } else {
             while (! feof($f)) {
                 $line = chop(fgets($f, 10240));
-                $line = ereg_replace('(.*)[;#].*', '\\1', $line);
-                if (ereg("^[ \t]*$", $line, $regs)) {
+                $line = preg_replace('/(.*)[;#].*/', '\\1', $line);
+                if (preg_match("/^[ \t]*$/", $line, $regs)) {
                     continue;
                 }
-                ereg("^[ \t]*([^ \t]+)[ \t]+([^ \t]+)", $line, $regs);
+                preg_match("/^[ \t]*([^ \t]+)[ \t]+([^ \t]+)/", $line, $regs);
                 $option = $regs[1];
                 $value = $regs[2];
 
                 switch ($option) {
+                    case 'nameserver':
+                        $nameservers = explode(' ', $regs[2]);
+                        foreach ($nameservers as $ns) {
+                            $this->nameservers[count($this->nameservers)] = $ns;
+                        }
+                        break;
                     case 'domain':
                         $this->domain = $regs[2];
                         break;
                     case 'search':
                         $this->searchlist[count($this->searchlist)] = $regs[2];
                         break;
-                    case 'nameserver':
-                        foreach (split(' ', $regs[2]) as $ns) {
-                            $this->nameservers[count($this->nameservers)] = $ns;
-                        }
-                        break;
                 }
             }
             fclose($f);
         }
     }
 
+    function set_nameservers($nameservers) {
+        if ($nameservers == '') return;
+        $this->nameservers = explode(' ', $nameservers);
+    }
+
     /* }}} */
     /* Net_DNS_Resolver::read_env() {{{ */
     /**
@@ -359,11 +392,11 @@ class Net_DNS_Resolver
     function read_env()
     {
         if (getenv('RES_NAMESERVERS')) {
-            $this->nameservers = split(' ', getenv('RES_NAMESERVERS'));
+            $this->set_nameservers(getenv('RES_NAMESERVERS'));
         }
 
         if (getenv('RES_SEARCHLIST')) {
-            $this->searchlist = split(' ', getenv('RES_SEARCHLIST'));
+            $this->searchlist = explode(' ', getenv('RES_SEARCHLIST'));
         }
 
         if (getenv('LOCALDOMAIN')) {
@@ -371,9 +404,9 @@ class Net_DNS_Resolver
         }
 
         if (getenv('RES_OPTIONS')) {
-            $env = split(' ', getenv('RES_OPTIONS'));
+            $env = explode(' ', getenv('RES_OPTIONS'));
             foreach ($env as $opt) {
-                list($name, $val) = split(':', $opt);
+                list($name, $val) = explode(':', $opt);
                 if ($val == '') {
                     $val = 1;
                 }
@@ -420,7 +453,7 @@ class Net_DNS_Resolver
      */
     function nextid()
     {
-        if ($GLOBALS['_Net_DNS_packet_id']++ > 65535) {
+		if (++$GLOBALS['_Net_DNS_packet_id'] > 65535) {
             $GLOBALS['_Net_DNS_packet_id']= 1;
         }
         return $GLOBALS['_Net_DNS_packet_id'];
@@ -665,12 +698,12 @@ class Net_DNS_Resolver
         $packet = $this->make_query_packet($packetORname, $qtype, $qclass);
         $packet_data = $packet->data();
 
-        if ($this->usevc != 0 || strlen($packet_data > 512)) {
+        if (($this->usevc != 0) || (strlen($packet_data) > 512)) {
             $ans = $this->send_tcp($packet, $packet_data);
         } else {
             $ans = $this->send_udp($packet, $packet_data);
 
-            if ($ans && $ans->header->tc && $this->igntc != 0) {
+            if (($ans) && ($ans->header->tc) && ($this->igntc == 0)) {
                 if ($this->debug) {
                     echo ";;\n;; packet truncated: retrying using TCP\n";
                 }
@@ -846,7 +879,7 @@ class Net_DNS_Resolver
             if ($sock[$ctr++] = fsockopen("udp://$nameserver", $this->port)) {
                 $peerhost[$ctr-1] = $nameserver;
                 $peerport[$ctr-1] = $this->port;
-                socket_set_blocking($sock[$ctr-1], false);
+                stream_set_blocking($sock[$ctr-1], 0);
             } else {
                 $ctr--;
             }
@@ -858,7 +891,8 @@ class Net_DNS_Resolver
             return null;
         }
 
-        for ($i = 0; $i < $this->retry; $i++, $retrans *= 2,
+        $retry = $this->retry;
+        for ($i = 0; $i < $retry; $i++, $retrans *= 2,
                 $timeout = (int) ($retrans / $ctr)) {
             if ($timeout < 1) {
                 $timeout = 1;
@@ -886,11 +920,15 @@ class Net_DNS_Resolver
                  * let's sleep for a few hundred microseconds to let the
                  * data come in from the network...
                  */
-                usleep(500);
+                $sleep = $this->sleep;
+                if ($sleep) {
+                    usleep($sleep / 2);
+                }
+
                 $buf = '';
                 while (! strlen($buf) && $timetoTO > (time() +
                             (double)microtime())) {
-                    socket_set_blocking($s, false);
+                    stream_set_blocking($s, 0);
                     if ($buf = fread($s, 512)) {
                         $this->answerfrom = $peerhost[$k];
                         $this->answersize = strlen($buf);
@@ -913,7 +951,9 @@ class Net_DNS_Resolver
                         }
                     }
                     // Sleep another 1/100th of a second... this sucks...
-                    usleep(1000);
+                    if ($sleep) {
+                        usleep($sleep / 2);
+                    }
                 }
 
             }
@@ -965,7 +1005,7 @@ class Net_DNS_Resolver
         }
         // Try each nameserver up to $this->retry times
         for ($i = 0; $i < $this->retry; $i++) {
-            if ($i != 0) {
+            if ($i !== 0) {
                 // Set the timeout for each retry based on the number of
                 // nameservers there is a connected socket for.
                 $retrans *= 2;
